import matplotlib.pyplot as plt
import pandas as pd


# Histogram of frequency distribution by fixed interval length
# length of bins_interval interval
# margin The size of the left and right margins set
def probability_distribution(data, bins_interval=1, margin=1):
    bins = range(int(min(data)), int(max(data)) + bins_interval - 1, bins_interval)
    print(len(bins))
    for i in range(0, len(bins)):
        print(bins[i])
    plt.xlim(min(data) - margin, max(data) + margin)
    plt.title("probability-distribution")
    plt.xlabel('Interval')
    plt.ylabel('Probability')
    plt.hist(x=data, bins=bins, histtype='bar', color=['r'])
    plt.show()


data_csv = pd.read_csv('../../data/trainData.csv')
data_csv['Timestamp'] = pd.to_datetime(data_csv['Timestamp'], unit='s', origin=pd.Timestamp('1970-01-01 08:00:00'))
data_csv = data_csv[data_csv['real'] != -1]
print(data_csv['real'])

fig = plt.figure(figsize=(16, 10))
plt.subplot(1, 2, 1)
data_csv['real'].plot.hist(grid=True, bins=30, rwidth=0.5)
plt.xlabel('Measured value of dissolved oxygen (mg/L)')
plt.ylabel('Counts')
plt.grid(axis='y', alpha=0.75)

rjy_con_list = data_csv['real']
diff_rjy = rjy_con_list.diff()[1:].round(decimals=4)
range_value = 0.05
diff_rjy = diff_rjy[(diff_rjy >= -range_value) & (diff_rjy <= range_value)]

plt.subplot(1, 2, 2)
diff_rjy.plot.hist(grid=True, bins=30, rwidth=0.5)
plt.xlabel('Difference sequence value of dissolved oxygen (part) (mg/L)')
plt.ylabel('Counts')
plt.savefig('ProbabilityDistribution.png', dpi=300, bbox_inches='tight')
plt.show()
